@@ -14,8 +14,8 @@
 #include <math.h>
 
 #include <glib.h>
+#include <gio/gio.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomevfs/gnome-vfs.h>
 
 #ifdef HAVE_NETWORK_MANAGER
 #include <dbus/dbus-glib.h>
@@ -232,7 +232,7 @@ guess_zone_from_tree (const gchar *localtime, ClockZoneTable *zones)
 }
 
 static gchar *current_zone = NULL;
-static GnomeVFSMonitorHandle *monitor = NULL;
+static GFileMonitor *monitor = NULL;
 
 static void
 parse_etc_sysconfig_clock (void)
@@ -281,10 +281,10 @@ out:
 }
 
 static void
-monitor_etc_sysconfig_clock (GnomeVFSMonitorHandle *handle,
-			     const gchar *monitor_uri,
-			     const gchar *info_uri,
-			     GnomeVFSMonitorEventType event_type,
+monitor_etc_sysconfig_clock (GFileMonitor *handle,
+			     GFile *file,
+			     GFile *other_file,
+			     GFileMonitorEvent event,
 			     gpointer user_data)
 {
 	parse_etc_sysconfig_clock ();
@@ -294,13 +294,21 @@ static const gchar *
 zone_from_etc_sysconfig_clock (void)
 {
 	if (monitor == NULL) {
-		parse_etc_sysconfig_clock ();
+		GFile *file;
 
-		gnome_vfs_monitor_add (&monitor,
-				       "/etc/sysconfig/clock",
-				       GNOME_VFS_MONITOR_FILE,
-				       monitor_etc_sysconfig_clock,
-				       NULL);
+		parse_etc_sysconfig_clock ();
+		
+		file = g_file_new_for_path ("/etc/sysconfig/clock");
+
+		monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE,
+					       NULL, NULL);
+
+		g_object_unref (file);
+
+		if (monitor)
+			g_signal_connect (G_OBJECT (monitor), "changed", 
+					  G_CALLBACK (monitor_etc_sysconfig_clock),
+					  NULL);
 	}
 
 	return current_zone;
@@ -465,6 +473,12 @@ clock_location_finalize (GObject *g_obj)
                 priv->weather_timeout = 0;
         }
 
+	if (monitor) {
+		g_file_monitor_cancel (monitor);
+		g_object_unref (monitor);
+		monitor = NULL;
+	}
+
         G_OBJECT_CLASS (clock_location_parent_class)->finalize (g_obj);
 }
 
@@ -631,17 +645,30 @@ glong
 clock_location_get_offset (ClockLocation *loc)
 {
         ClockLocationPrivate *priv = PRIVATE (loc);
-        glong sys_timezone;
+        glong sys_timezone, local_timezone;
 	glong offset;
+	time_t t;
+	struct tm *tm;
 
+	t = time (NULL);
+	
         unsetenv ("TZ");
-        tzset ();
+        tm = localtime (&t);
         sys_timezone = timezone;
 
-        setenv ("TZ", priv->timezone, 1);
-        tzset();
+	if (tm->tm_isdst > 0) {
+		sys_timezone -= 3600;
+	}
 
-        offset = timezone - sys_timezone;
+        setenv ("TZ", priv->timezone, 1);
+        tm = localtime (&t);
+	local_timezone = timezone;
+
+	if (tm->tm_isdst > 0) {
+		local_timezone -= 3600;
+	}
+
+        offset = local_timezone - sys_timezone;
 
         if (priv->sys_timezone) {
                 setenv ("TZ", priv->sys_timezone, 1);
@@ -653,18 +680,20 @@ clock_location_get_offset (ClockLocation *loc)
         return offset;
 }
 
-gboolean
-clock_location_make_current (ClockLocation *loc, GError **error)
+typedef struct {
+	ClockLocation *location;
+	GFunc callback;
+	gpointer data;
+	GDestroyNotify destroy;
+} MakeCurrentData;
+
+static void
+make_current_cb (gpointer data, GError *error)
 {
-        ClockLocationPrivate *priv = PRIVATE (loc);
-        gchar *filename;
-        gboolean ret;
+	MakeCurrentData *mcdata = data;
+        ClockLocationPrivate *priv = PRIVATE (mcdata->location);
 
-        filename = g_build_filename (SYSTEM_ZONEINFODIR, priv->timezone, NULL);
-        ret = set_system_timezone (filename, error);
-        g_free (filename);
-
-	if (ret) {
+	if (error == NULL) {
 		/* FIXME this ugly shortcut is necessary until we move the
  	  	 * current timezone tracking to clock.c and emit the
  	 	 * signal from there
@@ -673,7 +702,47 @@ clock_location_make_current (ClockLocation *loc, GError **error)
 		current_zone = g_strdup (priv->timezone);
 	}
 
-        return ret;
+	if (mcdata->callback)
+		mcdata->callback (mcdata->data, error);
+	else
+		g_error_free (error);
+}
+
+static void
+free_make_current_data (gpointer data)
+{
+	MakeCurrentData *mcdata = data;
+	
+	if (mcdata->destroy)
+		mcdata->destroy (mcdata->data);
+	
+	g_object_unref (mcdata->location);
+	g_free (mcdata);
+}
+
+void
+clock_location_make_current (ClockLocation *loc, 
+                             GFunc          callback,
+                             gpointer       data,
+                             GDestroyNotify destroy)
+{
+        ClockLocationPrivate *priv = PRIVATE (loc);
+        gchar *filename;
+	MakeCurrentData *mcdata;
+
+	mcdata = g_new (MakeCurrentData, 1);
+
+	mcdata->location = g_object_ref (loc);
+	mcdata->callback = callback;
+	mcdata->data = data;
+	mcdata->destroy = destroy;
+
+        filename = g_build_filename (SYSTEM_ZONEINFODIR, priv->timezone, NULL);
+        set_system_timezone_async (filename, 
+                                   (GFunc)make_current_cb, 
+				   mcdata,
+                                   free_make_current_data);
+        g_free (filename);
 }
 
 const gchar *
